$PathCam::DefaultPath = "Spline";
$PathCam::DefaultType = "Normal";
$PathCam::DefaultSpeed = 6;
$PathCam::Version = 1.0;

function serverCmdCreatePathCam(%client)
{
	if(!%client.isAdmin)
	{
		return;
	}
	if(isObject(%client.pathCam))
	{
		%client.pathCam.delete();
		%client.pathTimes = 0;
	}
	%client.pathCam = new PathCamera()
	{
		dataBlock = PathObserver;
		position = %client.getControlObject().getPosition();
		rotation = "0 0 1 0";
	};
	%client.pathCam.setState("stop");
	%client.bottomPrint("\c2*Path Camera Created*",3);
	%client.hasUsedPathCam = 0;
}

function serverCmdSetPath(%client,%speed,%type,%path)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	if(%client.pathTimes > 20)
	{
		%client.bottomPrint("\c2*You have maxed out the number of knots in your path!*",2);
		return;
	}
	%transform = %client.getControlObject().getTransform();
	if(%speed $= "")
	{
		%camSpeed = $PathCam::DefaultSpeed;
	}
	else
	{
		%camSpeed = %speed;
	}
	if(%type $= "")
	{
		%camType = $PathCam::DefaultType;
	}
	else
	{
		if(%type $= "Position")
		{
			%type = "Position Only";
		}
		%camType = %type;
	}
	if(%path $= "")
	{
		%camPath = $PathCam::DefaultPath;
	}
	else
	{
		%camPath = %path;
	}
	%client.pathTimes++;
	if(%client.pathTimes == 1)
	{
		%client.pathCam.pushBack(%transform,%camSpeed,%camType,%camPath);
		%client.pathCam.setPosition(1.0);
		%client.pathCam.popFront();
		%client.bottomPrint("\c2*"@%client.pathTimes@"/20 knots in your camera path*",3);
	}
	else
	{
		%client.pathCam.pushBack(%transform,%camSpeed,%camType,%camPath);
		%client.bottomPrint("\c2*"@%client.pathTimes@"/20 knots in your camera path*",3);
	}
}

function serverCmdPathCamStart(%client)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	%time = 50;
	if(!%client.hasUsedPathCam)
	{
		%client.bottomPrint("\c2*Initiating Camera*",2);
		%time = 2000;
		%client.hasUsedPathCam = 1;
	}
	if(%client.getControlObject().getClassName() $= "Camera" && isObject(%client.player))
	{
		serverCmdDropCameraAtPlayer(%client);
		serverCmdDropPlayerAtCamera(%client);
	}
	%client.pathCam.setPosition(0.0);
	%client.setControlObject(%client.pathCam);
	%client.schedule(%time,"countDownStart");
}
function GameConnection::countDownStart(%this)
{
	if(!%this.isAdmin || !isObject(%this.pathCam))
	{
		return;
	}
	%this.bottomPrint("\c2*Starting Path Camera in 3..*",1);
	%this.schedule(1000,bottomPrint,"\c2*Starting Path Camera in 2..*",1);
	%this.schedule(2000,bottomPrint,"\c2*Starting Path Camera in 1..*",1);
	%this.pathCam.schedule(3000,setTarget,%client.pathTimes);
	%this.pathCam.schedule(3100,setState,"forward");
}
function serverCmdGoToPathCam(%client)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	%client.setControlObject(%client.pathCam);
}

function serverCmdPathCamStop(%client)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	%client.pathCam.setState("stop");
}
function serverCmdPathCamGoTo(%client,%float)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	if(%float $= "")
	{
		%float = 0.0;
	}
	%client.pathCam.setPosition(%float);
}
function serverCmdPathCamGo(%client)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	%client.pathCam.setState("forward");
}
function serverCmdPathCamEnd(%client)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	%client.setControlObject(%client.player);
	%client.pathCam.setState("stop");
}
function serverCmdPathCamHelp(%client)
{
	messageClient(%client,'',"\c2Path Camera Mod V."@$PathCam::Version);
	messageClient(%client,'',"\c2/CreatePathCam (creates personal path camera if you are an admin and clears your old path camera if exists)");
	messageClient(%client,'',"\c2/setPath [%speed,%type,%path] (sets the next knot for your camera path where your current control object is looking, max 20, arguments are optional)");
	messageClient(%client,'',"\c2      -  %speed is any positive number; %type can be Normal, Position Only, or Kink; and %path can be Linear or Spline");
	messageClient(%client,'',"\c2/pathCamStart (initiates the path camera)");
	messageClient(%client,'',"\c2/pathCamEnd (sends you back to your player)");
	messageClient(%client,'',"\c2/pathCamGo (pushes the camera forward, in case camera stops for some reason)");
	messageClient(%client,'',"\c2/pathCamStop (stops the camera where it is)");
	messageClient(%client,'',"\c2/pathCamGoTo [%position] (sends the path camera to a place along the path, where 0.0 is the first knot, 1.0 is second, etc..)");
	messageClient(%client,'',"\c2/goToPathCam (sends you to the path camera)");
	messageClient(%client,'',"\c2/pathCamReset (resets the path camera and clears all knots)");
}
function serverCmdPathCamReset(%client)
{
	if(!%client.isAdmin || !isObject(%client.pathCam))
	{
		return;
	}
	%client.pathTimes = 0;
	if(isObject(%client.pathCam))
	{
		%client.pathCam.reset(6);
	}
	if(%client.getControlObject().getClassName() $= "Path Camera" && isObject(%client.player))
	{
		%client.setControlObject(%client.player);
	}
	%client.pathCam.setState("stop");
	%client.bottomPrint("\c2*Path Camera Reset",3);
}